"""
    Ory Keto API

    Documentation for all of Ory Keto's REST APIs. gRPC is documented separately.   # noqa: E501

    The version of the OpenAPI document: v0.9.0-alpha.0
    Contact: hi@ory.sh
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import ory_keto_client
from ory_keto_client.model.subject_set import SubjectSet
globals()['SubjectSet'] = SubjectSet
from ory_keto_client.model.relation_tuple import RelationTuple


class TestRelationTuple(unittest.TestCase):
    """RelationTuple unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRelationTuple(self):
        """Test RelationTuple"""
        # FIXME: construct object with mandatory attributes with example values
        # model = RelationTuple()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
